@@ -2,9 +2,9 @@ context("Check ceteris_paribus_2d() function")
 
 test_that("Output rf",{
   library("DALEX")
-  library("randomForest")
+  library("ranger")
   set.seed(59)
-  apartments_rf_model <- randomForest(m2.price ~., data = apartments)
+  apartments_rf_model <- ranger(m2.price ~., data = apartments)
   explainer_rf <- explain(apartments_rf_model,
        data = apartmentsTest[,2:6], y = apartmentsTest$m2.price, verbose = FALSE)
   new_apartment <- apartmentsTest[1, ]
